package com.ruoyi.system.service;

import com.ruoyi.system.domain.PoOperLog;

import java.util.List;

/**
 * 操作日志记录Service接口
 * @date 2023-01-15
 */
public interface IPoOperLogService
{
    /**
     * 查询操作日志记录
     *
     * @param operId 操作日志记录主键
     * @return 操作日志记录
     */
    public PoOperLog selectPoOperLogByOperId(Long operId);

    /**
     * 查询操作日志记录列表
     *
     * @param poOperLog 操作日志记录
     * @return 操作日志记录集合
     */
    public List<PoOperLog> selectPoOperLogList(PoOperLog poOperLog);

    /**
     * 新增操作日志记录
     *
     * @param poOperLog 操作日志记录
     * @return 结果
     */
    public int insertPoOperLog(PoOperLog poOperLog);

    /**
     * 修改操作日志记录
     *
     * @param poOperLog 操作日志记录
     * @return 结果
     */
    public int updatePoOperLog(PoOperLog poOperLog);

    /**
     * 批量删除操作日志记录
     *
     * @param operIds 需要删除的操作日志记录主键集合
     * @return 结果
     */
    public int deletePoOperLogByOperIds(Long[] operIds);

    /**
     * 删除操作日志记录信息
     *
     * @param operId 操作日志记录主键
     * @return 结果
     */
    public int deletePoOperLogByOperId(Long operId);
}
